Learn R Programming

redatamx (version 1.2.1)

redatam_open: Open dictionary

Description

Open a REDATAM database. This function returns an ID than can be used in functions to query data.

Usage

redatam_open(dictionary_name)

Value

ID than can be used in functions to query data.

Arguments

dictionary_name

Dictionary file name

Author

Jaime Salvador

Examples

Run this code
if (FALSE) {
dic<-redatam_open("path/to/rxdb")
}

Run the code above in your browser using DataLab