redatam_query: Execute a Redatam command from text
Description
Execute a Redatam command: TABLE or AREALIST.
This function removes all the rows that contain total, na or mv values. Additionally, this function removes the "mask" columns.
Usage
redatam_query(dic, spc, tot.omit = TRUE)
Value
If the program contains more than one table, the method returns the last table (in the SPC program) as a data frame.
All the tables are registered (as data frames) in a custom environment called ‘redatam::outputs’.