powered by
Open a REDATAM database. This function returns an ID than can be used in functions to query data.
redatam_open(dictionary_name)
ID than can be used in functions to query data.
Dictionary file name
Jaime Salvador
if (FALSE) { dic<-redatam_open("path/to/rxdb") }
Run the code above in your browser using DataLab